﻿package motta.menu
{
	
	/**
	* ...
	* @author lucas motta - http://lucasmotta.com
	* @version 1.0
	* 
	* @example of use:
	* 
	* 			import motta.menu.MenuG94
	* 
	* 			var menu:MenuG94
	* 
	* 			function init()
	* 			{
	* 				menu = new MenuG94(show:int, border:int, padding:int)
	* 				menu.add(String, Function, Object)
	* 				menu.add("Lucas Motta", callBack, {sex:"male"})
	* 				addChild(menu)
	* 
	* 				createButtons()
	* 			}
	* 
	* 			function callBack(event:MouseEvent)
	* 			{
	* 				trace(event.target.params.sex)
	* 			}
	* 
	* 			function createButtons():void
	*			{
	*				nextMc.buttonMode = prevMc.buttonMode = true
	*				nextMc.mouseChildren = prevMc.mouseChildren = false
	*				nextMc.addEventListener(MouseEvent.CLICK, menu.nextPage)
	*				prevMc.addEventListener(MouseEvent.CLICK, menu.prevPage)
	*				menu.addEventListener(MouseEvent.MOUSE_WHEEL, menu.onWheel);
	*			}	
	* 			
	* 			init()
	*/
	
	import flash.display.DisplayObject;
	import flash.display.MovieClip;
	import flash.events.MouseEvent;
	import fl.motion.easing.Exponential;
	import flash.text.TextField;
	import gs.TweenLite;
	
	public class MenuG94 extends MovieClip
	{
		private var _array:Array
		private var _show:int
		private var _page:int
		private var _border:int
		private var _padding:int
		
		public function MenuG94(show:int=5, border:int=1, padding:int=40):void
		{
			_array = new Array();
			_show = show
			_page = 0
			_border = border
			_padding = padding
		}
		
		public function add(str:String, fcn:Function, params:Object=null):void
		{
			var item = new ItemG94(_array.length, params)
			addChild(item)
			//
			item.txt.text = str;
			//
			item.buttonMode = true;
			item.mouseChildren = false;
			item.addEventListener(MouseEvent.CLICK, fcn);
			//
			_array.push(item)
			reposition()
		}
		
		private function reposition(time:int=0):void
		{
			var i:int
			for (i; i < _array.length; i++)
			{
				var item = _array[i]
				var posY:int = ((item.id - _page) * item.height ) + (item.id * _border) - (_page * _border);
				//
				if ((i < _page) || (i >= _page + _show))
				{
					item.mouseEnabled = false
					var diff:int = (i < _page) ? posY - _padding : posY + _padding;
					TweenLite.to(item, time, { y:diff , alpha:0, ease:Exponential.easeOut } );
				}
				else
				{
					item.mouseEnabled = true
					TweenLite.to(item, time, { y:posY, alpha:1, ease:Exponential.easeOut } );
				}
			}
		}
		
		/**
		 * EVENTS
		*/
		
		public function nextPage(event:MouseEvent)
		{
			if (_page < _array.length - _show)
			{
				_page++
				reposition(1)
			}
		}
		
		public function prevPage(event:MouseEvent)
		{
			if (_page > 0)
			{
				_page--
				reposition(1)
			}
		}
		
		public function onWheel(event:MouseEvent)
		{
			(event.delta < 0) ? nextPage(null) : prevPage(null)
		}
		
	}
	
}